@@ -298,14 +298,14 @@ def one_of(args):
     pass  # pragma: no cover
 
 
-@overload
+@overload  # noqa: F811
 def one_of(*args):
     # type: (SearchStrategy[Any]) -> SearchStrategy[Any]
     pass  # pragma: no cover
 
 
-def one_of(*args):
-    # Mypy workaround alert:  Any is too loose above; the return paramater
+def one_of(*args):  # noqa: F811
+    # Mypy workaround alert:  Any is too loose above; the return parameter
     # should be the union of the input parameters.  Unfortunately, Mypy <=0.600
     # raises errors due to incompatible inputs instead.  See #1270 for links.
     # v0.610 doesn't error; it gets inference wrong for 2+ arguments instead.
@@ -435,8 +435,10 @@ def floats(
     # type: (...) -> SearchStrategy[float]
     """Returns a strategy which generates floats.
 
-    - If min_value is not None, all values will be >= min_value.
-    - If max_value is not None, all values will be <= max_value.
+    - If min_value is not None, all values will be ``>= min_value``
+      (or ``> min_value`` if ``exclude_min``).
+    - If max_value is not None, all values will be ``<= max_value``
+      (or ``< max_value`` if ``exclude_max``).
     - If min_value or max_value is not None, it is an error to enable
       allow_nan.
     - If both min_value and max_value are not None, it is an error to enable
@@ -454,6 +456,7 @@ def floats(
 
     The exclude_min and exclude_max argument can be used to generate numbers
     from open or half-open intervals, by excluding the respective endpoints.
+    Excluding either signed zero will also exclude the other.
     Attempting to exclude an endpoint which is None will raise an error;
     use ``allow_infinity=False`` to generate finite floats.  You can however
     use e.g. ``min_value=float("-inf"), exclude_min=True`` to exclude only
@@ -520,12 +523,20 @@ def floats(
         exclude_min or (min_arg is not None and min_value < min_arg)
     ):
         min_value = next_up(min_value, width)
-        assert min_value > min_arg or min_value == min_arg == 0  # type: ignore
+        if min_value == min_arg:
+            assert min_value == min_arg == 0
+            assert is_negative(min_arg) and not is_negative(min_value)
+            min_value = next_up(min_value, width)
+        assert min_value > min_arg  # type: ignore
     if max_value is not None and (
         exclude_max or (max_arg is not None and max_value > max_arg)
     ):
         max_value = next_down(max_value, width)
-        assert max_value < max_arg or max_value == max_arg == 0  # type: ignore
+        if max_value == max_arg:
+            assert max_value == max_arg == 0
+            assert is_negative(max_value) and not is_negative(max_arg)
+            max_value = next_down(max_value, width)
+        assert max_value < max_arg  # type: ignore
 
     if min_value == float(u"-inf"):
         min_value = None
@@ -658,14 +669,14 @@ def sampled_from(elements):
     pass  # pragma: no cover
 
 
-@overload
+@overload  # noqa: F811
 def sampled_from(elements):
     # type: (Type[enum.Enum]) -> SearchStrategy[Any]
     # `SearchStrategy[Enum]` is unreliable due to metaclass issues.
     pass  # pragma: no cover
 
 
-@defines_strategy
+@defines_strategy  # noqa: F811
 def sampled_from(elements):
     """Returns a strategy which generates any value present in ``elements``.
 
@@ -959,8 +970,8 @@ def characters(
     """Generates unicode text type (unicode on python 2, str on python 3)
     characters following specified filtering rules.
 
-    - When no filtering rules are specifed, any character can be produced.
-    - If ``min_codepoint`` or ``max_codepoint`` is specifed, then only
+    - When no filtering rules are specified, any character can be produced.
+    - If ``min_codepoint`` or ``max_codepoint`` is specified, then only
       characters having a codepoint in that range will be produced.
     - If ``whitelist_categories`` is specified, then only characters from those
       Unicode categories will be produced. This is a further restriction,
@@ -1815,7 +1826,7 @@ def datetimes(
     there.
 
     Alternatively, you can create a list of the timezones you wish to allow
-    (e.g. from the standard library, ``datetutil``, or ``pytz``) and use
+    (e.g. from the standard library, :pypi:`dateutil`, or :pypi:`pytz`) and use
     :py:func:`sampled_from`.  Ensure that simple values such as None or UTC
     are at the beginning of the list for proper minimisation.
 
@@ -1823,7 +1834,7 @@ def datetimes(
     """
     # Why must bounds be naive?  In principle, we could also write a strategy
     # that took aware bounds, but the API and validation is much harder.
-    # If you want to generate datetimes between two particular momements in
+    # If you want to generate datetimes between two particular moments in
     # time I suggest (a) just filtering out-of-bounds values; (b) if bounds
     # are very close, draw a value and subtract its UTC offset, handling
     # overflows and nonexistent times; or (c) do something customised to
